@@ -118,6 +118,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("azw", &["application/vnd.amazon.ebook"]),
     ("b16", &["image/vnd.pco.b16"]),
     ("bas", &["text/plain"]),
+    ("bash", &["application/x-shellscript", "application/x-sh"]),
     ("bat", &["application/x-msdownload"]),
     ("bcpio", &["application/x-bcpio"]),
     ("bdf", &["application/x-font-bdf"]),
@@ -196,7 +197,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("cil", &["application/vnd.ms-artgalry"]),
     ("cjs", &["application/node"]),
     ("cla", &["application/vnd.claymore"]),
-    ("class", &["application/java-vm", "application/x-java-applet"]),
+    ("class", &["application/x-java", "application/java-vm", "application/x-java-applet"]),
     ("clkk", &["application/vnd.crick.clicker.keyboard"]),
     ("clkp", &["application/vnd.crick.clicker.palette"]),
     ("clkt", &["application/vnd.crick.clicker.template"]),
@@ -617,6 +618,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("kpr", &["application/vnd.kde.kpresenter"]),
     ("kpt", &["application/vnd.kde.kpresenter"]),
     ("kpxx", &["application/vnd.ds-keypoint"]),
+    ("kra", &["application/x-krita"]),
     ("ksp", &["application/vnd.kde.kspread"]),
     ("ktr", &["application/vnd.kahootz"]),
     ("ktx", &["image/ktx"]),
@@ -938,7 +940,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("pgm", &["image/x-portable-graymap"]),
     ("pgn", &["application/x-chess-pgn"]),
     ("pgp", &["application/pgp-encrypted"]),
-    ("php", &["application/x-httpd-php"]),
+    ("php", &["application/x-php", "application/x-httpd-php"]),
     ("pic", &["image/pict", "image/x-pict"]),
     ("pict", &["image/pict", "image/x-pict"]),
     ("pkg", &["application/octet-stream"]),
@@ -1143,7 +1145,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("sgl", &["application/vnd.stardivision.writer-global"]),
     ("sgm", &["text/sgml"]),
     ("sgml", &["text/sgml"]),
-    ("sh", &["application/x-sh"]),
+    ("sh", &["application/x-shellscript", "application/x-sh"]),
     ("shar", &["application/x-shar"]),
     ("shex", &["text/shex"]),
     ("shf", &["application/shf+xml"]),
@@ -1239,7 +1241,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("svg", &["image/svg+xml"]),
     ("svgz", &["image/svg+xml"]),
     ("swa", &["application/x-director"]),
-    ("swf", &["application/x-shockwave-flash"]),
+    ("swf", &["application/vnd.adobe.flash.movie", "application/x-shockwave-flash"]),
     ("swi", &["application/vnd.aristanetworks.swi"]),
     ("swidtag", &["application/swid+xml"]),
     ("sxc", &["application/vnd.sun.xml.calc"]),
@@ -1263,7 +1265,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("teicorpus", &["application/tei+xml"]),
     ("testrunconfig", &["application/xml"]),
     ("testsettings", &["application/xml"]),
-    ("tex", &["application/x-tex"]),
+    ("tex", &["text/x-tex", "application/x-tex"]),
     ("texi", &["application/x-texinfo"]),
     ("texinfo", &["application/x-texinfo"]),
     ("text", &["text/plain"]),
@@ -1482,6 +1484,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("xbd", &["application/vnd.fujixerox.docuworks.binder"]),
     ("xbm", &["image/x-xbitmap"]),
     ("xca", &["application/xcap-caps+xml"]),
+    ("xcf", &["image/x-xcf"]),
     ("xcs", &["application/calendar+xml"]),
     ("xdf", &["application/xcap-diff+xml"]),
     ("xdm", &["application/vnd.syncml.dm+xml"]),
